@@ -1,8 +1,8 @@
 import os
 # unset so to trigger exceptions and track use: RDBaseDir=os.environ['RDBASE']
-RDCodeDir=os.path.join(r'C:\bld\rdkit_1553619596137\_h_env\Lib\site-packages','rdkit')
+RDCodeDir=os.path.join(r'D:\bld\rdkit_1620892659631\_h_env\Lib\site-packages','rdkit')
 # not really hard-coded alternative RDCodeDir=os.path.dirname(__file__)
-_share = os.path.join(r'C:/bld/rdkit_1553619596137/_h_env/Library', r'share/RDKit')
+_share = os.path.join(r'D:/bld/rdkit_1620892659631/_h_env/Library', r'share/RDKit')
 RDDataDir=os.path.join(_share,'Data')
 RDDocsDir=os.path.join(_share,'Docs')
 RDProjDir=os.path.join(_share,'Projects')
